Merge "Patch to fix test_aggregates_basic_ops and test_aggregates tests" into mcp/caracal
diff --git a/tempest/api/volume/base.py b/tempest/api/volume/base.py
index b93ade5..3d82c8f 100644
--- a/tempest/api/volume/base.py
+++ b/tempest/api/volume/base.py
@@ -269,8 +269,11 @@
         tenant_network = self.get_tenant_network()
 
         # Since microversion v2.37 'networks' field is required
-        if self.compute_request_microversion >= '2.37' and 'networks'\
-                not in kwargs:
+        if (
+            self.compute_request_microversion >= '2.37' and
+            'networks' not in kwargs and
+            not kwargs.get("validatable", False)
+        ):
             kwargs['networks'] = 'none'
 
         body, _ = compute.create_test_server(
diff --git a/tempest/scenario/manager.py b/tempest/scenario/manager.py
index 316f248..212c1b3 100644
--- a/tempest/scenario/manager.py
+++ b/tempest/scenario/manager.py
@@ -1206,10 +1206,10 @@
                                             server=server,
                                             username=username)
 
         # Default the directory in which to write the timestamp file to /tmp
         # and only use the mount_path as the target directory if we mounted
         # dev_name to mount_path.
-        target_dir = '/tmp'
+        target_dir = '/root'
         if dev_name is not None:
             ssh_client.make_fs(dev_name, fs=fs)
             ssh_client.exec_command('sudo mount /dev/%s %s' % (dev_name,
@@ -1243,10 +1243,10 @@
                                             server=server,
                                             username=username)
 
         # Default the directory from which to read the timestamp file to /tmp
         # and only use the mount_path as the target directory if we mounted
         # dev_name to mount_path.
-        target_dir = '/tmp'
+        target_dir = '/root'
         if dev_name is not None:
             ssh_client.mount(dev_name, mount_path)
             target_dir = mount_path
@@ -1206,10 +1206,10 @@
                                             username=username)
 
-        # Default the directory in which to write the timestamp file to /tmp
+        # Default the directory in which to write the timestamp file to /root
         # and only use the mount_path as the target directory if we mounted
         # dev_name to mount_path.
@@ -1243,10 +1243,10 @@
                                             username=username)
 
-        # Default the directory from which to read the timestamp file to /tmp
+        # Default the directory from which to read the timestamp file to /root
         # and only use the mount_path as the target directory if we mounted
         # dev_name to mount_path.